@@ -1,7 +1,7 @@
 import enum
 from graphql_api import GraphQLAPI
 
-from graphql_mcp.server import GraphQLMCPServer
+from graphql_mcp.server import GraphQLMCP
 
 api = GraphQLAPI()
 
@@ -28,17 +28,14 @@ class DemoApp:
         return {"key": "ai_model", "value": "x"}
 
 
-mcp_server = GraphQLMCPServer(api=api)
+mcp_server = GraphQLMCP.from_api(api=api)
 
 
 # Add an addition tool
 @mcp_server.tool()
-def set_preference(key: PreferenceKey, value: str) -> bool:
-    """Set a preference"""
-    if isinstance(key, PreferenceKey):
-        return True
-    else:
-        return False
+def clear_preferences() -> bool:
+    """Clear all preferences"""
+    return True
 
 
 if __name__ == "__main__":
