@@ -9,7 +9,7 @@ from mcp.types import TextContent
 from typing import cast
 
 from graphql_api import field
-from graphql_mcp.server import add_tools_from_schema, GraphQLMCPServer
+from graphql_mcp.server import add_tools_from_schema, GraphQLMCP
 
 
 def get_result_text(result):
@@ -48,9 +48,13 @@ async def test_from_graphql_schema():
     # Ensure the schema actually mapped the argument to a GraphQL Enum
     try:
         from graphql import GraphQLEnumType, get_named_type
-        arg_type = get_named_type(schema.query_type.fields["echoPreference"].args["key"].type)  # type: ignore[attr-defined]
+        # type: ignore[attr-defined]
+        assert schema.query_type is not None
+        arg_type = get_named_type(
+            schema.query_type.fields["echoPreference"].args["key"].type)
         if not isinstance(arg_type, GraphQLEnumType):
-            pytest.skip("PreferenceKey was not mapped to a GraphQL Enum by graphql-api; cannot assert instance coercion")
+            pytest.skip(
+                "PreferenceKey was not mapped to a GraphQL Enum by graphql-api; cannot assert instance coercion")
     except Exception:
         pass
 
@@ -326,7 +330,7 @@ async def test_from_graphql_schema_with_existing_server():
 @pytest.mark.asyncio
 async def test_from_schema_class_method():
     """
-    Tests the GraphQLMCPServer.from_schema class method.
+    Tests the GraphQLMCP.from_schema class method.
     """
     try:
         from graphql_api import GraphQLAPI
@@ -343,7 +347,7 @@ async def test_from_schema_class_method():
 
     schema, _ = api.build_schema()
 
-    mcp_server = GraphQLMCPServer.from_schema(schema, name="TestServer")
+    mcp_server = GraphQLMCP(schema=schema, name="TestServer")
     assert isinstance(mcp_server, FastMCP)
     assert mcp_server.name == "TestServer"
 
@@ -358,7 +362,7 @@ async def test_from_schema_class_method():
 @pytest.mark.asyncio
 async def test_from_graphql_api_class_method():
     """
-    Tests the GraphQLMCPServer.from_graphql_api class method.
+    Tests the GraphQLMCP.from_graphql_api class method.
     """
     try:
         from graphql_api import GraphQLAPI
@@ -373,7 +377,7 @@ async def test_from_graphql_api_class_method():
 
     api = GraphQLAPI(root_type=MyAPI)
 
-    mcp_server = GraphQLMCPServer.from_api(api, name="TestFromAPI")
+    mcp_server = GraphQLMCP.from_api(api, name="TestFromAPI")
     assert isinstance(mcp_server, FastMCP)
     assert mcp_server.name == "TestFromAPI"
 
@@ -406,7 +410,8 @@ async def test_from_graphql_schema_core_only():
         fields={
             "hello": GraphQLField(
                 GraphQLString,
-                args={"name": GraphQLArgument(GraphQLString, default_value="world")},
+                args={"name": GraphQLArgument(
+                    GraphQLString, default_value="world")},
                 resolve=resolve_hello,
             )
         },
@@ -681,7 +686,7 @@ async def test_enum_argument_mcp_vs_graphql_mapping():
             # Returns whether we actually received the Enum instance
             return isinstance(key, PreferenceKey)
 
-    mcp_server = GraphQLMCPServer(api=api)
+    mcp_server = GraphQLMCP.from_api(api=api)
 
     # Add a direct MCP tool that expects the Enum annotation
     @mcp_server.tool
@@ -722,7 +727,7 @@ async def test_string_enum_argument_mcp_vs_graphql_mapping():
             # Returns whether we actually received the Enum instance
             return isinstance(key, PreferenceKey)
 
-    mcp_server = GraphQLMCPServer(api=api)
+    mcp_server = GraphQLMCP.from_api(api=api)
 
     # Add a direct MCP tool that expects the Enum annotation
     @mcp_server.tool
@@ -763,7 +768,7 @@ async def test_int_enum_argument_mcp_vs_graphql_mapping():
             # Returns whether we actually received the Enum instance
             return isinstance(key, PreferenceKey)
 
-    mcp_server = GraphQLMCPServer(api=api)
+    mcp_server = GraphQLMCP.from_api(api=api)
 
     # Add a direct MCP tool that expects the Enum annotation
     @mcp_server.tool
@@ -800,7 +805,7 @@ async def test_dict_mcp_vs_graphql_mapping():
             # Returns whether we actually received the Enum instance
             return {"key": "ai_model", "value": "x"}
 
-    mcp_server = GraphQLMCPServer(api=api)
+    mcp_server = GraphQLMCP.from_api(api=api)
 
     # Add a direct MCP tool that expects the Enum annotation
     @mcp_server.tool
