@@ -3,10 +3,9 @@
 import asyncio
 import pytest
 import aiohttp
-import json
 from unittest.mock import AsyncMock, patch, MagicMock
 
-from graphql_mcp.server import GraphQLMCPServer
+from graphql_mcp.server import GraphQLMCP
 from fastmcp.client import Client
 from mcp.types import TextContent
 from typing import cast
@@ -32,7 +31,7 @@ MOCK_SCHEMA_RESPONSE = {
             "types": [
                 {
                     "kind": "OBJECT",
-                    "name": "Query", 
+                    "name": "Query",
                     "description": None,
                     "fields": [
                         {
@@ -46,13 +45,16 @@ MOCK_SCHEMA_RESPONSE = {
                                     "defaultValue": '"World"'
                                 }
                             ],
-                            "type": {"kind": "NON_NULL", "name": None, "ofType": {"kind": "SCALAR", "name": "String", "ofType": None}},
+                            "type": {
+                                "kind": "NON_NULL", "name": None,
+                                "ofType": {"kind": "SCALAR", "name": "String", "ofType": None}
+                            },
                             "isDeprecated": False,
                             "deprecationReason": None
                         },
                         {
                             "name": "add",
-                            "description": "Adds two numbers", 
+                            "description": "Adds two numbers",
                             "args": [
                                 {
                                     "name": "a",
@@ -61,7 +63,7 @@ MOCK_SCHEMA_RESPONSE = {
                                     "defaultValue": None
                                 },
                                 {
-                                    "name": "b", 
+                                    "name": "b",
                                     "description": None,
                                     "type": {"kind": "NON_NULL", "name": None, "ofType": {"kind": "SCALAR", "name": "Int", "ofType": None}},
                                     "defaultValue": None
@@ -80,7 +82,7 @@ MOCK_SCHEMA_RESPONSE = {
                 {
                     "kind": "OBJECT",
                     "name": "Mutation",
-                    "description": None, 
+                    "description": None,
                     "fields": [
                         {
                             "name": "multiply",
@@ -120,7 +122,7 @@ MOCK_SCHEMA_RESPONSE = {
                     "possibleTypes": None
                 },
                 {
-                    "kind": "SCALAR", 
+                    "kind": "SCALAR",
                     "name": "Int",
                     "description": "Built-in Int",
                     "fields": None,
@@ -140,11 +142,11 @@ def create_mock_response(json_data=None):
     """Create a mock HTTP response for GraphQL requests."""
     mock_response = AsyncMock()
     mock_response.status = 200
-    
+
     if json_data and 'query' in json_data:
         query = json_data['query'].strip()
         variables = json_data.get('variables', {})
-        
+
         # Handle introspection (including first call which may not have query key)
         if 'IntrospectionQuery' in query or '__schema' in query or 'queryType' in query:
             mock_response.json = AsyncMock(return_value=MOCK_SCHEMA_RESPONSE)
@@ -171,23 +173,23 @@ def create_mock_response(json_data=None):
     else:
         # Default introspection response for schema fetching during server creation
         mock_response.json = AsyncMock(return_value=MOCK_SCHEMA_RESPONSE)
-    
+
     return mock_response
 
 
 @pytest.mark.asyncio
 async def test_real_remote_graphql_server():
     """Test against a mock remote GraphQL server."""
-    
+
     def mock_post(url, json=None, **kwargs):
         mock_cm = AsyncMock()
         mock_cm.__aenter__ = AsyncMock(return_value=create_mock_response(json))
         mock_cm.__aexit__ = AsyncMock(return_value=None)
         return mock_cm
-    
+
     with patch('aiohttp.ClientSession.post', side_effect=mock_post):
         # Create MCP server from a mock remote URL
-        mcp_server = GraphQLMCPServer.from_remote_url(
+        mcp_server = GraphQLMCP.from_remote_url(
             url="http://mock-server.example.com/graphql",
             name="Test Remote GraphQL",
             timeout=10
@@ -221,19 +223,19 @@ async def test_real_remote_graphql_server():
 @pytest.mark.asyncio
 async def test_remote_server_with_headers():
     """Test remote server accepts custom headers."""
-    
+
     headers_received = {}
-    
+
     def mock_post_with_headers(url, json=None, headers=None, **kwargs):
         headers_received.update(headers or {})
         mock_cm = AsyncMock()
         mock_cm.__aenter__ = AsyncMock(return_value=create_mock_response(json))
         mock_cm.__aexit__ = AsyncMock(return_value=None)
         return mock_cm
-    
+
     with patch('aiohttp.ClientSession.post', side_effect=mock_post_with_headers):
         # Create MCP server with custom headers
-        mcp_server = GraphQLMCPServer.from_remote_url(
+        mcp_server = GraphQLMCP.from_remote_url(
             url="http://mock-server.example.com/graphql",
             headers={
                 "X-Custom-Header": "test-value",
@@ -245,15 +247,15 @@ async def test_remote_server_with_headers():
 
         # The server should be created successfully with headers
         assert mcp_server is not None
-        
+
         # Test that it works by calling a simple tool
         async with Client(mcp_server) as client:
             tools = await client.list_tools()
             assert len(tools) > 0
-            
+
             result = await client.call_tool("hello", {"name": "HeaderTest"})
             assert get_result_text(result) == "Hello, HeaderTest!"
-            
+
         # Verify headers were sent
         assert "X-Custom-Header" in headers_received
         assert headers_received["X-Custom-Header"] == "test-value"
@@ -264,23 +266,24 @@ async def test_remote_server_with_headers():
 @pytest.mark.asyncio
 async def test_remote_server_connection_error_handling():
     """Test proper error handling when server is not available."""
-    
+
     def mock_connection_error(*args, **kwargs):
         raise aiohttp.ClientConnectorError(
             connection_key=MagicMock(),
             os_error=OSError("Connection refused")
         )
-    
+
     with patch('aiohttp.ClientSession.post', side_effect=mock_connection_error):
         try:
             # This should fail because the connection is mocked to fail
-            GraphQLMCPServer.from_remote_url(
+            GraphQLMCP.from_remote_url(
                 url="http://unreachable-server.example.com/graphql",
                 timeout=2,
                 name="Non-existent Server"
             )
-            pytest.fail("Expected connection error but server creation succeeded")
-            
+            pytest.fail(
+                "Expected connection error but server creation succeeded")
+
         except Exception as e:
             # Should get a connection error
             error_str = str(e).lower()
@@ -292,19 +295,19 @@ async def test_remote_server_connection_error_handling():
 @pytest.mark.asyncio
 async def test_remote_server_with_ssl_disabled():
     """Test remote server with SSL verification disabled."""
-    
+
     ssl_config_captured = {}
-    
+
     def mock_post_capture_ssl(*args, ssl=None, json=None, **kwargs):
         ssl_config_captured['ssl'] = ssl
         mock_cm = AsyncMock()
         mock_cm.__aenter__ = AsyncMock(return_value=create_mock_response(json))
         mock_cm.__aexit__ = AsyncMock(return_value=None)
         return mock_cm
-    
+
     with patch('aiohttp.ClientSession.post', side_effect=mock_post_capture_ssl):
         # Create MCP server with SSL verification disabled
-        mcp_server = GraphQLMCPServer.from_remote_url(
+        mcp_server = GraphQLMCP.from_remote_url(
             url="https://mock-server.example.com/graphql",
             verify_ssl=False,
             timeout=10,
@@ -312,7 +315,7 @@ async def test_remote_server_with_ssl_disabled():
         )
 
         assert mcp_server is not None
-        
+
         # Verify it works
         async with Client(mcp_server) as client:
             tools = await client.list_tools()
@@ -322,17 +325,17 @@ async def test_remote_server_with_ssl_disabled():
 @pytest.mark.asyncio
 async def test_remote_server_with_bearer_token():
     """Test bearer token authentication."""
-    
+
     auth_headers_received = {}
-    
+
     def mock_auth_post(url, json=None, headers=None, **kwargs):
         auth_headers_received.update(headers or {})
-        
+
         # Check for authorization header
         auth_header = headers.get('Authorization', '') if headers else ''
-        
+
         mock_cm = AsyncMock()
-        
+
         if not auth_header.startswith('Bearer '):
             # Simulate 401 Unauthorized
             mock_response = AsyncMock()
@@ -353,15 +356,16 @@ async def test_remote_server_with_bearer_token():
                 mock_cm.__aenter__ = AsyncMock(return_value=mock_response)
             else:
                 # Valid token - return normal response
-                mock_cm.__aenter__ = AsyncMock(return_value=create_mock_response(json))
-        
+                mock_cm.__aenter__ = AsyncMock(
+                    return_value=create_mock_response(json))
+
         mock_cm.__aexit__ = AsyncMock(return_value=None)
         return mock_cm
-    
+
     with patch('aiohttp.ClientSession.post', side_effect=mock_auth_post):
         # Test without token - should fail
         try:
-            GraphQLMCPServer.from_remote_url(
+            GraphQLMCP.from_remote_url(
                 url="http://auth-required.example.com/graphql",
                 timeout=5,
                 name="Auth Required Server"
@@ -372,21 +376,21 @@ async def test_remote_server_with_bearer_token():
             assert any(word in error_str for word in [
                 "401", "authentication", "unauthorized", "error"
             ]), f"Expected auth error, got: {e}"
-        
+
         # Test with correct token - should succeed
-        mcp_server = GraphQLMCPServer.from_remote_url(
+        mcp_server = GraphQLMCP.from_remote_url(
             url="http://auth-required.example.com/graphql",
             headers={"Authorization": "Bearer test-token-123"},
             timeout=5,
             name="Authenticated Server"
         )
-        
+
         assert mcp_server is not None
-        
+
         async with Client(mcp_server) as client:
             tools = await client.list_tools()
             assert len(tools) > 0
-        
+
         # Verify the correct token was sent
         assert "Authorization" in auth_headers_received
         assert auth_headers_received["Authorization"] == "Bearer test-token-123"
@@ -395,9 +399,9 @@ async def test_remote_server_with_bearer_token():
 @pytest.mark.asyncio
 async def test_remote_server_query_execution():
     """Test direct GraphQL query execution."""
-    
+
     queries_received = []
-    
+
     def mock_post_capture_queries(url, json=None, **kwargs):
         if json:
             queries_received.append(json)
@@ -405,27 +409,29 @@ async def test_remote_server_query_execution():
         mock_cm.__aenter__ = AsyncMock(return_value=create_mock_response(json))
         mock_cm.__aexit__ = AsyncMock(return_value=None)
         return mock_cm
-    
+
     with patch('aiohttp.ClientSession.post', side_effect=mock_post_capture_queries):
         # Create server
-        mcp_server = GraphQLMCPServer.from_remote_url(
+        mcp_server = GraphQLMCP.from_remote_url(
             url="http://mock-server.example.com/graphql",
             name="Query Test Server",
             timeout=10
         )
-        
+
         # Execute through MCP client
         async with Client(mcp_server) as client:
             result = await client.call_tool("hello", {"name": "QueryTest"})
             assert get_result_text(result) == "Hello, QueryTest!"
-        
+
         # Verify queries were made
         assert len(queries_received) > 0
-        
+
         # Should have introspection query and actual query
-        introspection_found = any('__schema' in q.get('query', '') for q in queries_received)
-        hello_query_found = any('hello' in q.get('query', '') for q in queries_received)
-        
+        introspection_found = any('__schema' in q.get(
+            'query', '') for q in queries_received)
+        hello_query_found = any('hello' in q.get('query', '')
+                                for q in queries_received)
+
         assert introspection_found, "Should have made introspection query"
         assert hello_query_found, "Should have made hello query"
 
@@ -433,13 +439,13 @@ async def test_remote_server_query_execution():
 @pytest.mark.asyncio
 async def test_remote_server_timeout_handling():
     """Test handling of request timeouts."""
-    
+
     def mock_timeout_post(*args, **kwargs):
         raise asyncio.TimeoutError("Request timed out")
-    
+
     with patch('aiohttp.ClientSession.post', side_effect=mock_timeout_post):
         try:
-            GraphQLMCPServer.from_remote_url(
+            GraphQLMCP.from_remote_url(
                 url="http://slow-server.example.com/graphql",
                 timeout=1,  # Very short timeout
                 name="Slow Server"
@@ -455,7 +461,7 @@ async def test_remote_server_timeout_handling():
 @pytest.mark.asyncio
 async def test_remote_server_graphql_errors():
     """Test handling of GraphQL errors from server."""
-    
+
     def mock_error_response(url, json=None, **kwargs):
         mock_response = AsyncMock()
         mock_response.status = 200
@@ -472,10 +478,10 @@ async def test_remote_server_graphql_errors():
         mock_cm.__aenter__ = AsyncMock(return_value=mock_response)
         mock_cm.__aexit__ = AsyncMock(return_value=None)
         return mock_cm
-    
+
     with patch('aiohttp.ClientSession.post', side_effect=mock_error_response):
         try:
-            GraphQLMCPServer.from_remote_url(
+            GraphQLMCP.from_remote_url(
                 url="http://error-server.example.com/graphql",
                 name="Error Server"
             )
@@ -490,4 +496,4 @@ async def test_remote_server_graphql_errors():
 if __name__ == "__main__":
     # Run tests manually for development
     import pytest
-    pytest.main([__file__, "-v"])
\ No newline at end of file
+    pytest.main([__file__, "-v"])
